# REST client for the UW Libraries web services

[![Build Status](https://api.travis-ci.org/uw-it-aca/uw-restclients-libraries.svg?branch=master)](https://travis-ci.org/uw-it-aca/uw-restclients-libraries)
[![Coverage Status](https://coveralls.io/repos/github/uw-it-aca/uw-restclients-libraries/badge.svg?branch=master)](https://coveralls.io/github/uw-it-aca/uw-restclients-libraries?branch=master)
[![PyPi Version](https://img.shields.io/pypi/v/uw-restclients-libraries.svg)](https://pypi.python.org/pypi/uw-restclients-libraries)
![Python versions](https://img.shields.io/pypi/pyversions/uw-restclients-libraries.svg)
